function str = AUTRES_Contents(timeResponseData)
% Summarize the contents of a time response structure
%--------------------------------------------------------------------------------
%
% PURPOSE
%
% Generate summary of the contents of the specified time response structure.
%
% INPUTS
%
% timeResponseData - Time response structure whose contents are to be summarized.
%
% OUTPUTS
%
% str - (Optional) String containing the contents summary.
%       If str is omitted the summary is displayed in the Matlab console.
%
% AUTHOR
%
% David Vowles, Power Systems Dynamics Group,
% School of Electrical & Electronic Engineering,
% The University of Adelaide, Adealaide, South Australia
%
% David.Vowles@adelaide.edu.au
%
% DATE
% 
% 21/12/2013
%
%--------------------------------------------------------------------------------


   str1 = '';
   
   Notes = [];
   if (isfield(timeResponseData,'Notes'))
      Notes = timeResponseData.Notes;
   end
   
   filename = [];
   if (isfield(timeResponseData,'filename'))
      filename = timeResponseData.filename;
   end
     
   l = char('-'*ones(1,80));
   str1 = [ str1, sprintf('%s\n',l) ];
   
   if (not(isempty(filename)))   
      str1 = [str1, sprintf('Data loaded from file: %s\n',filename)]
   end
   
   if (not(isempty(Notes)))
      str1 = [ str1, sprintf('%s\n',Notes{:}) ];
   end

   str1 = [ str1, sprintf('\nChannels ...\n\n') ];
      
   for i = 1:length(timeResponseData.channelNames)
      str1 = [ str1, sprintf('%3d  %s (%s)\n', ...
                     i, ...
                     timeResponseData.channelNames{i}, ...
                     timeResponseData.channelUnits{i}) ];
   end
   
   str1 = [ str1, sprintf('%s\n',l) ];

   if (nargout == 1)
      str = str1;
   else
      fprintf('%s',str1);
   end
         