function [IsFound,tt,yy,chanName,chanUnits] = AUTRES_Extract(timeResponseData,var)
% Extract time response of one variable from a time response data structure
%--------------------------------------------------------------------------------
%
% PURPOSE
%
% Extract time response of one variable from a time response data structure
% 
% INPUTS
%
% timeResponseData - Time response structure from which a single time-response
%                    is to be extracted.
%
% var - String containing the name of the variable whose time response is to
%       extracted. (The search for var in timeResponseData is case insensitive).
%
% OUTPUTS
%
% IsFound   - Flag to indicate if the specified time response has been found
%             = 1 if the variable is found; = 0 otherwise.
% tt        - Time vector (s)
% yy        - yy(i) is the value of the selected variable var at time tt(i)
% chanName  - String containing the name of the selected channel in the same
%             case as it is in the TimeResponseData structure.
% chanUnits - String containing the units of yy.
%
% AUTHOR
%
% David Vowles, Power Systems Dynamics Group,
% School of Electrical & Electronic Engineering,
% The University of Adelaide, Adealaide, South Australia
%
% David.Vowles@adelaide.edu.au
%
% DATE
% 
% 21/12/2013
%
%--------------------------------------------------------------------------------

   IsFound   = 0;
   tt        = [];
   yy        = [];
   chanName  = '';
   chanUnits = '';
   nchan     = length(timeResponseData.channelNames);
   
   for i = 1:nchan
      if (strcmpi(timeResponseData.channelNames{i}, var))
         IsFound = 1;
         tt = timeResponseData.TT(:);
         yy = timeResponseData.YY(:,i);
         chanName  = timeResponseData.channelNames{i};
         chanUnits = timeResponseData.channelUnits{i};
         break
      end
   end
   
